@@ -90,14 +90,29 @@ def x => y => z
   d="dd"
 />&lt;/a>
 
+
+/*
+  /*
+    multi-line comment
+  */
+*/
+
+
+// multi-line string
+"""
+hello
+there
+"""
+
 (1 +   // give up early by typing two blank lines
 
 
-
+// defining and using quoted names should work (ticket #323)
+def `match` = 1 
+val x = `match` 
 
 </code>.text
 
-
   /** A writer that skips the first line of text.  The first
    *  line of interpreter output is skipped because it includes
    *  a version number. */
