@@ -21,4 +21,12 @@ object Test extends Application {
   println(s2.drop(-1))
   println(s2.dropWhile(_ > 0))
   println
+
+  val s3 = Stream.range(1, 1000) //100000 (ticket #153: Stackoverflow)
+  println(s3.length)
+
+  // ticket #153
+  def powers(x: Int) = if ((x&(x-1)) == 0) Some(x) else None
+  println(s3.flatMap(powers).reverse.head)
+
 }
